        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 19 <strong>control</strong><br>0,3,5,6,10,13,18,20,21,25,26,27,33,38,39,40,41,44,48';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 16 <br>1,2,7,14,15,22,23,29,30,32,34,36,43,46,49,50';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>4,9,16,28,31,35,42,45';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>4</strong> representante: <strong>11</strong> miembros: 4 <br>11,12,17,24';}
       if(rr==2 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>5</strong> representante: <strong>37</strong> miembros: 4 <br>8,19,37,47';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 19 <strong>control</strong><br>0,3,5,6,10,13,18,20,21,25,26,27,33,38,39,40,41,44,48';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 16 <br>1,2,7,14,15,22,23,29,30,32,34,36,43,46,49,50';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>4,9,16,28,31,35,42,45';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>4</strong> representante: <strong>11</strong> miembros: 4 <br>11,12,17,24';}
       if(rr==9 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>5</strong> representante: <strong>37</strong> miembros: 4 <br>8,19,37,47';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 19 <strong>control</strong><br>0,3,5,6,10,13,18,20,21,25,26,27,33,38,39,40,41,44,48';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 16 <br>1,2,7,14,15,22,23,29,30,32,34,36,43,46,49,50';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>4,9,16,28,31,35,42,45';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>4</strong> representante: <strong>11</strong> miembros: 4 <br>11,12,17,24';}
       if(rr==10 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>5</strong> representante: <strong>37</strong> miembros: 4 <br>8,19,37,47';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 19 <strong>control</strong><br>0,3,5,6,10,13,18,20,21,25,26,27,33,38,39,40,41,44,48';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 16 <br>1,2,7,14,15,22,23,29,30,32,34,36,43,46,49,50';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>4,9,16,28,31,35,42,45';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>4</strong> representante: <strong>11</strong> miembros: 4 <br>11,12,17,24';}
       if(rr==11 && cc==5){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>5</strong> representante: <strong>37</strong> miembros: 4 <br>8,19,37,47';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 19 <strong>control</strong><br>0,3,5,6,10,13,18,20,21,25,26,27,33,38,39,40,41,44,48';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 16 <br>1,2,7,14,15,22,23,29,30,32,34,36,43,46,49,50';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>4,9,16,28,31,35,42,45';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>4</strong> representante: <strong>11</strong> miembros: 4 <br>11,12,17,24';}
       if(rr==12 && cc==5){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>5</strong> representante: <strong>37</strong> miembros: 4 <br>8,19,37,47';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 19 <strong>control</strong><br>0,3,5,6,10,13,18,20,21,25,26,27,33,38,39,40,41,44,48';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 16 <br>1,2,7,14,15,22,23,29,30,32,34,36,43,46,49,50';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>4,9,16,28,31,35,42,45';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>4</strong> representante: <strong>11</strong> miembros: 4 <br>11,12,17,24';}
       if(rr==13 && cc==5){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>5</strong> representante: <strong>37</strong> miembros: 4 <br>8,19,37,47';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 19 <strong>control</strong><br>0,3,5,6,10,13,18,20,21,25,26,27,33,38,39,40,41,44,48';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 16 <br>1,2,7,14,15,22,23,29,30,32,34,36,43,46,49,50';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>4,9,16,28,31,35,42,45';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>4</strong> representante: <strong>11</strong> miembros: 4 <br>11,12,17,24';}
       if(rr==14 && cc==5){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>5</strong> representante: <strong>37</strong> miembros: 4 <br>8,19,37,47';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 19 <strong>control</strong><br>0,3,5,6,10,13,18,20,21,25,26,27,33,38,39,40,41,44,48';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 16 <br>1,2,7,14,15,22,23,29,30,32,34,36,43,46,49,50';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>4,9,16,28,31,35,42,45';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>4</strong> representante: <strong>11</strong> miembros: 4 <br>11,12,17,24';}
       if(rr==15 && cc==5){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>5</strong> representante: <strong>37</strong> miembros: 4 <br>8,19,37,47';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 19 <strong>control</strong><br>0,3,5,6,10,13,18,20,21,25,26,27,33,38,39,40,41,44,48';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 16 <br>1,2,7,14,15,22,23,29,30,32,34,36,43,46,49,50';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>4,9,16,28,31,35,42,45';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>4</strong> representante: <strong>11</strong> miembros: 4 <br>11,12,17,24';}
       if(rr==16 && cc==5){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260621 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>5</strong> representante: <strong>37</strong> miembros: 4 <br>8,19,37,47';}
}
